@@ -4,6 +4,7 @@ class Manager(object):
     # should be re-defined in a subclass
     state_name = None
     object_type = None
+    resource_type = None
 
     def __init__(self, api):
         self.api = api
@@ -35,9 +36,13 @@ class GetByIdMixin(object):
                 return obj
 
         if not only_local:
-            obj = eval('self.api.get_' + self.object_type)(obj_id)
-            if self.object_type in obj and \
-               'error' not in obj[self.object_type]:
-                return obj[self.object_type]
+            return eval('self.api.get_' + self.object_type)(obj_id)
 
         return None
+
+class SyncMixin(object):
+    """
+    Syncs this specific type of objects.
+    """
+    def sync(self):
+        return self.api.sync(resource_types=[self.resource_type])
